---
layout: default
---

# Reagent Validation

Several practices for antibody validation have been previously described [[1-3](#references)]. These include evaluating the immunolabeling pattern of a particular antibody with positive and negative controls, assessing colocalization with orthogonal markers, and using knockout or knockdown cell lines.

We appreciate the time it takes to submit a knowledge-base entry. For this reason, we elected for a validation standard that encourages rigor without being oppressively burdensome. Furthermore, the knowledge-base is designed to be self-correcting, allowing entries to be refined as more people contribute their data:
* An ideal entry would include validation images showing the labeling pattern of an antibody in positive and negative control tissues. Alternatively, the image(s) may depict the proper subcellular and tissue distribution of the antibody. Please include details on the controls used, colocalization with other markers, and descriptions of the cellular and subcellular distribution of the antibody (membrane, cytoplasm, nuclei) in the notes section of the supporting material file.
* If images were not captured at the time of testing, we accept entries that describe why an antibody is recommended or not recommended for a particular target. Please see [this entry](./supporting_material/CD11b_Unconjugated/0000-0003-4379-8967.md) as an example.
* Oftentimes, an antibody works better in a particular conjugate or tissue. We encourage contributors to provide such details as [shown here](./supporting_material/CD11c_AF594/0000-0003-4379-8967.md).
* For reagents published in peer-reviewed manuscripts, the supporting materials can link to an appropriate publication as [listed here](./supporting_material/CD44_AF700/0000-0003-1431-1398.md).

If you have any questions, please post on the [knowledge-base GitHub discussion forum](https://github.com/IBEXImagingCommunity/ibex_imaging_knowledge_base/discussions). Thank you!

## References:
1. Hickey, J. W. et al., “Spatial mapping of protein composition and tissue
organization: A primer for multiplexed antibody-based imaging,” *Nat
Methods*, vol. 19, no. 2, pp. 284–295, 2022, doi:
[10.1038/s41592-021-01316-y](https://doi.org/10.1038/s41592-021-01316-y).
1. Uhlen, M. et al. "A proposal for validation of antibodies," *Nat
Methods*, vol. 13, no. 10, pp. 823-827, 2016, doi:[10.1038/nmeth.3995](https://doi.org/10.1038/nmeth.3995).
1. Bordeaux, J. et al., "Antibody validation," *Biotechniques* vol. 48, no. 3, pp. 197-209, 2010, doi:[10.2144/000113382](https://doi.org/10.2144/000113382).

